package com.ibm.vap.cciadapter.ims;

import javax.resource.cci.Connection;
/*
 * Source File Name : IMSAdapter.java
 * Licensed Materials - Property of IBM
 * 5655-F37
 * (C) Copyright IBM Corp. 1983, 2002
 */
import com.ibm.vap.cciadapter.*;
/**
 * This server adapter class is used by the VisualAge Pacbase Runtime to communicate with
 * the server using J2EE connectors through IMS Connect protocol.
 * <P>
 * Sample code :
 * <blockquote>
 * <pre>
 *	com.ibm.connector2.ims.ico.IMSManagedConnectionFactory imsmcf = new com.ibm.connector2.ims.ico.IMSManagedConnectionFactory();
 *	imsmcf.setHostName("xxx.xxx.xxx.xxx.xxx");
 *	imsmcf.setPortNumber(new Integer(4000));
 *	imsmcf.setDataStoreName("DATASTORE");
 *	imsmcf.setTraceLevel(new Integer(2));
 *	imsmcf.setUserName("USER");
 *	imsmcf.setPassword("PASSWORD");
 *	imsmcf.setGroupName("GROUPNAME");
 *	 com.ibm.connector2.ims.ico.IMSConnectionFactory imscf= (com.ibm.connector2.ims.ico.IMSConnectionFactory)imsmcf.createConnectionFactory();
 *
 *	com.ibm.connector2.ims.ico.IMSConnectionSpec imscs = new com.ibm.connector2.ims.ico.IMSConnectionSpec();
 *	com.ibm.connector2.ims.ico.IMSInteractionSpec imsis = new com.ibm.connector2.ims.ico.IMSInteractionSpec();
 *	imsis.setInteractionVerb(com.ibm.connector2.ims.ico.IMSInteractionSpec.SYNC_SEND_RECEIVE);
 *	 
 *	try {
 *		com.ibm.vap.cciadapter.ims.IMSAdapter imsa = new com.ibm.vap.cciadapter.ims.IMSAdapter(imscf, imscs, imsis);
 *		imsa.setHostCodePage("Cp037");
 *		imsa.setTransactionName("TRANS");
 *		imsa.setCommareaLength(8192);
 *		com.ibm.vap.generated.proxies.CustomerProxyLv proxy = new com.ibm.vap.generated.proxies.CustomerProxyLv();
 *		proxy.setServerAdapter(imsa);
 *		proxy.selectInstances();
 *		return proxy.rows();
 *	} catch (com.ibm.vap.generic.CommunicationError ce) {
 *		return ce.getMessage();
 *	}
 * </pre> 
 * </blockquote>
 * @see com.ibm.vap.generic.ServerAdapter
 * @since 3.0v06
 * @version 3.0v06
 */
public class IMSAdapter extends com.ibm.vap.cciadapter.CCIAdapter {
	String transactionName = null;
	int commareaLength = 0;
	private final static String copyright = "Licensed Materials - Property of IBM\n5655-F37\n(C) Copyright IBM Corp. 1983, 2002. All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP\nSchedule Contract with IBM Corp.";
/**
 * IMSAdapter constructor comment.
 */
public IMSAdapter() {
	super();
}
/**
 * IMSAdapter constructor comment.
 * @param connectionFactory javax.resource.cci.ConnectionFactory
 * @param connection javax.resource.cci.ConnectionSpec
 * @param interaction javax.resource.cci.InteractionSpec
 */
public IMSAdapter(javax.resource.cci.ConnectionFactory connectionFactory, javax.resource.cci.ConnectionSpec connection, javax.resource.cci.InteractionSpec interaction) {
	super(connectionFactory, connection, interaction);
}
protected CCIRequester createRequester(Connection connection) {
	return new IMSRequester(this, connection);
}
/**
 * retrieves the messageLength attribut.
 * @return the commarea length
 */
public int getCommareaLength() {
	return commareaLength;
}
public String getTransactionName() {
	return transactionName;
}
/**
 * Sets the commareaLength attribut.
 * @param length of the commarea
 */
public void setCommareaLength(int newValue)
{
	int oldValue = commareaLength;
	commareaLength = newValue;
	firePropertyChange( "commareaLength", new Integer(oldValue), new Integer(newValue));	
}
public void setTransactionName(String tn) {
	transactionName = tn;
}
}
