package com.ibm.vap.cciadapter.ims;

/*
 * Source File Name : IMSVapRecord.java
 * IBM Confidential
 * OCO Source Materials
 * 5655-F37
 * (C) Copyright IBM Corp. 1983, 2002
 * The source code for this program is not published or otherwise divested of its trade secrets,
 * irrespective of what has been deposited with the U. S. Copyright Office.
 */
import com.ibm.vap.generic.CommunicationError;
/**
 * VapRecord dedicated to IMSAdapter/IMSRequester using CCI library
 */
public class IMSVapRecord extends com.ibm.vap.cciadapter.VapRecord {
	public final static int TRANSACTION_NAME_SIZE = 8;
	private final static String copyright = "Licensed Materials - Property of IBM\n5655-F37\n(C) Copyright IBM Corp. 1983, 2002. All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP\nSchedule Contract with IBM Corp.";
public IMSVapRecord(int length, com.ibm.vap.cciadapter.CCIAdapter cciAdapter) {
	super(length, cciAdapter);
}
public IMSVapRecord(com.ibm.vap.cciadapter.CCIAdapter cciAdapter) {
	super(cciAdapter);
}
private IMSAdapter getIMSAdapter() {
	return (IMSAdapter) cciAdapter;
}
public void getMessage(char[] message, int offset, int length)
	throws java.io.IOException {
	try {
		String out =
			new String(buffer, offset + 4, length, getIMSAdapter().getHostCodePage());
		out.getChars(0, length, message, offset);
	} catch (java.io.UnsupportedEncodingException uee) {
		throw new CommunicationError("Byte to Char Conversion Error", uee);
	}
}
/**
 * Transfer the input message in the buffer array.
 * @param mess to be transfered in the byte array
 * @param offset defines the starting position
 * @param length of the message to transfer
 */
public void setMessage(char[] message, int offset, int length)
	throws java.io.IOException {
	// Allocate the buffer in order to store input bytes
	int headerLength = 2 + 2 + TRANSACTION_NAME_SIZE; // LL + ZZ + TransactionName
	int sentLength = headerLength + length;

	buffer = new byte[sentLength];

	// Transaction name stored beginning at the 4th byte
	StringBuffer transactionName = new StringBuffer(TRANSACTION_NAME_SIZE);
	transactionName.append(getIMSAdapter().getTransactionName());
	while (transactionName.length() < TRANSACTION_NAME_SIZE)
		transactionName.append(' ');
	try {
		byte[] transaction =
			transactionName.toString().getBytes(getIMSAdapter().getHostCodePage());
		System.arraycopy(transaction, 0, buffer, 4, TRANSACTION_NAME_SIZE);
	} catch (java.io.UnsupportedEncodingException uee) {
		throw new CommunicationError("Char to Byte Conversion Error", uee);
	}

	// Applicative part of the message
	try {
		byte[] inData =
			new String(message, offset, length).getBytes(getIMSAdapter().getHostCodePage());
		System.arraycopy(inData, 0, buffer, headerLength, length);
	} catch (java.io.UnsupportedEncodingException uee) {
		throw new CommunicationError("Char to Byte Conversion Error", uee);
	}

	// Header part of the message
	// LL
	int ll = sentLength;
	buffer[0] = (byte) (short) (ll / 256);
	buffer[1] = (byte) (short) (ll % 256);
	// ZZ
	int zz = 0;
	buffer[2] = (byte) (short) (zz / 256);
	buffer[3] = (byte) (short) (zz % 256);
}
}
